# Generated by roxygen2: do not edit by hand

export(pca)
export(pcreg)
export(robust_pca)
export(robust_pcreg)
export(sparse_pca)
export(sparse_pcreg)
export(supervised_pca)
export(supervised_pcreg)
importFrom(elasticnet,spca)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_equal)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_col)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(ggrepel,geom_text_repel)
importFrom(grid,arrow)
importFrom(grid,unit)
importFrom(gridExtra,grid.arrange)
importFrom(psych,KMO)
importFrom(psych,cortest.bartlett)
importFrom(robustbase,covMcd)
importFrom(scales,percent_format)
importFrom(stats,complete.cases)
importFrom(stats,cor)
importFrom(stats,lm)
importFrom(stats,prcomp)
importFrom(stats,sd)
importFrom(stats,step)
