% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/robust_pcreg.R
\name{robust_pcreg}
\alias{robust_pcreg}
\title{Robust Principal Component Regression (Robust PCR)}
\usage{
robust_pcreg(data, y, K = NULL, threshold = 0.9, verbose = FALSE)
}
\arguments{
\item{data}{A data frame or matrix}

\item{y}{Response variable name (character)}

\item{K}{Number of components (optional)}

\item{threshold}{Variance threshold for automatic K selection}

\item{verbose}{Logical; print detailed output}
}
\value{
A list containing Robust PCR outputs
}
\description{
Performs Robust PCA using Minimum Covariance Determinant (MCD)
followed by regression on robust principal components.
Includes PCA suitability tests, summary, loadings,
scree plot, biplot, and regression models.
}
\examples{
data(mtcars)
Result <- robust_pcreg(mtcars, y = "mpg")
}
