% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/robust_pca.R
\name{robust_pca}
\alias{robust_pca}
\title{Robust Principal Component Analysis (Robust PCA)}
\usage{
robust_pca(data, K = NULL, threshold = 0.9, verbose = FALSE)
}
\arguments{
\item{data}{Numeric data frame or matrix}

\item{K}{Number of components (auto if NULL)}

\item{threshold}{Variance threshold for K selection}

\item{verbose}{Logical; if TRUE prints progress messages}
}
\value{
List of results
}
\description{
Performs Robust PCA using MCD estimator with automatic K selection,
PCA suitability tests (Bartlett & KMO), scree plot and biplot.
}
\examples{
data(iris)
Result <- robust_pca(iris[, 1:4])
}
