% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pca.R
\name{pca}
\alias{pca}
\title{Principal Component Analysis (Custom Scree Style)}
\usage{
pca(data, scale. = TRUE, center = TRUE, verbose = FALSE)
}
\arguments{
\item{data}{A data frame or matrix}

\item{scale.}{Logical; scale variables}

\item{center}{Logical; center variables}

\item{verbose}{Logical; if TRUE, prints Bartlett and KMO results.}
}
\value{
List with Bartlett test, KMO, loadings, scores, variance
}
\description{
Performs PCA with Bartlett test, KMO measure,
and visualizes scree plot and biplot (custom style).
}
\examples{
{
data(mtcars)
Result <- pca(mtcars)
}
}
