% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pc_reg.R
\name{pcreg}
\alias{pcreg}
\title{Principal Component Regression (PCR)}
\usage{
pcreg(data, y, scale. = TRUE, center = TRUE, verbose = FALSE)
}
\arguments{
\item{data}{A data frame or matrix}

\item{y}{Response variable name}

\item{scale.}{Logical; should variables be scaled?}

\item{center}{Logical; should variables be centered?}

\item{verbose}{Logical; print summaries?}
}
\value{
A list containing PCA results,
regression models, diagnostics, and plots.
}
\description{
Performs Principal Component Analysis (PCA) on predictors
followed by regression using selected principal components.
Includes Bartlett's test, KMO measure,
scree plot, biplot, and backward model selection.
}
\examples{
data(mtcars)
result <- pcreg(mtcars, y = "mpg")
}
